grub-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH 1/3] Decrease minimal gfxterm size to 10x6


From: Vladimir Serbinenko
Subject: [PATCH 1/3] Decrease minimal gfxterm size to 10x6
Date: Thu, 16 May 2024 22:34:42 +0300

10x6 is still marginally usable. Erroring out may leave user without any console

Signed-off-by: Vladimir Serbinenko <phcoder@gmail.com>
---
 grub-core/term/gfxterm.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/grub-core/term/gfxterm.c b/grub-core/term/gfxterm.c
index addad5ee2..e8734a388 100644
--- a/grub-core/term/gfxterm.c
+++ b/grub-core/term/gfxterm.c
@@ -234,12 +234,13 @@ grub_virtual_screen_setup (unsigned int x, unsigned int y,
 
   /*
    * There must be a minimum number of rows and columns for the screen to
    * make sense. Arbitrarily pick half of 80x24. If either dimensions is 0
    * we would allocate 0 bytes for the text_buffer.
    */
-  if (virtual_screen.columns < 40 || virtual_screen.rows < 12)
+  if (virtual_screen.columns < 10 || virtual_screen.rows < 6)
     return grub_error (GRUB_ERR_BAD_FONT,
-                      "font: glyphs too large to fit on screen");
+                      "font: glyphs too large to fit on screen (%dx%d)",
+                      virtual_screen.columns, virtual_screen.rows);
 
   /* Allocate memory for text buffer.  */
   virtual_screen.text_buffer =
@@ -234,12 +234,13 @@ grub_virtual_screen_setup (unsigned int x, unsigned int y,
   /*
    * There must be a minimum number of rows and columns for the screen to
-   * make sense. Arbitrarily pick half of 80x24. If either dimensions is 0
+   * make sense. Arbitrarily pick 10x6. If either dimensions is 0
    * we would allocate 0 bytes for the text_buffer.
    */
-- 
2.39.2




reply via email to

[Prev in Thread] Current Thread [Next in Thread]